@@ -1819,12 +1819,9 @@ def process_neg_idx(
     function to convert all the negative indices to positive before
     send it to Tensorflow.
     """
-    data_shape = tf_shape(input_tensor=data)
-    if data.get_shape().is_fully_defined():
-        if not isinstance(indices, np.ndarray):
-            indices_shape = indices.get_shape().as_list()
-        else:
-            indices_shape = indices.shape
+    data_shape = data.shape
+    if None not in data_shape:
+        indices_shape = indices.shape
     else:
         indices_shape = tf_shape(input_tensor=indices)
     if batch_dims > 0:
@@ -1942,4 +1939,68 @@ def disable_unnecessary_transpose(
                         a=input_tensor_2,
                         perm=reverse_perm,
                     )
-    return graph_node_input_1, graph_node_input_2, input_tensor_1, input_tensor_2
\ No newline at end of file
+    return graph_node_input_1, graph_node_input_2, input_tensor_1, input_tensor_2
+
+
+def shape_unmatched_special_avoidance_workaround(
+    *,
+    graph_node_input_1,
+    graph_node_input_2,
+    input_tensor_1,
+    input_tensor_2,
+    tf_layers_dict,
+):
+    # At least one True value for same_input_shape_as_onnx
+    # At least one True value in nhwc_flags
+    # same_input_shape_as_onnx == True and nhwc_flags == False and 3D or 4D or 5D tensor is NHWC transposed
+    nhwc_flag_1 = False
+    same_input_shape_as_onnx_1 = False
+    if isinstance(input_tensor_1, gs.Variable):
+        nhwc_flag_1 =tf_layers_dict[input_tensor_1.name]['nhwc'] \
+            if 'nhwc' in tf_layers_dict[input_tensor_1.name].keys() else False
+        graph_node_input_1_shape = [
+            dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
+        ]
+        same_input_shape_as_onnx_1 = True if len(graph_node_input_1_shape) > 0 \
+            and graph_node_input_1_shape == tf_layers_dict[input_tensor_1.name]['tf_node'].shape else False
+    else:
+        nhwc_flag_1 = False
+        graph_node_input_1_shape = [
+            dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
+        ]
+        same_input_shape_as_onnx_1 = True if len(graph_node_input_1_shape) > 0 \
+            and graph_node_input_1_shape == input_tensor_1.shape else False
+    nhwc_flag_2 = False
+    same_input_shape_as_onnx_2 = False
+    if isinstance(input_tensor_2, gs.Variable):
+        nhwc_flag_2 =tf_layers_dict[input_tensor_2.name]['nhwc'] \
+            if 'nhwc' in tf_layers_dict[input_tensor_2.name].keys() else False
+        graph_node_input_2_shape = [
+            dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
+        ]
+        same_input_shape_as_onnx_2 = True if len(graph_node_input_2_shape) > 0 \
+            and graph_node_input_2_shape == tf_layers_dict[input_tensor_2.name]['tf_node'].shape else False
+    else:
+        nhwc_flag_2 = False
+        graph_node_input_2_shape = [
+            dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
+        ]
+        same_input_shape_as_onnx_2 = True if len(graph_node_input_2_shape) > 0 \
+            and graph_node_input_2_shape == input_tensor_2.shape else False
+
+    same_input_shape_as_onnxs = [same_input_shape_as_onnx_1, same_input_shape_as_onnx_2]
+    nhwc_flags = [nhwc_flag_1, nhwc_flag_2]
+    if True in same_input_shape_as_onnxs and True in nhwc_flags:
+        values = [input_tensor_1, input_tensor_2]
+        for idx, (same_input_shape_as_onnx, nhwc_flag) in enumerate(zip(same_input_shape_as_onnxs, nhwc_flags)):
+            if same_input_shape_as_onnx and not nhwc_flag:
+                if len(values[idx].shape) == 3:
+                    values[idx] = tf.transpose(a=values[idx], perm=[0,2,1])
+                elif len(values[idx].shape) == 4:
+                    values[idx] = tf.transpose(a=values[idx], perm=[0,2,3,1])
+                elif len(values[idx].shape) == 5:
+                    values[idx] = tf.transpose(a=values[idx], perm=[0,2,3,4,1])
+        input_tensor_1 = values[0]
+        input_tensor_2 = values[1]
+
+    return input_tensor_1, input_tensor_2
